@@ -10,6 +10,13 @@
 #' @importFrom digest digest
 #' @importFrom shiny isTruthy
 #' @importFrom utils packageVersion sessionInfo
+#' @examples
+#' \donttest{
+#' certificate_df(x = list(data_formatted = data.frame(a = 1:3, b = 4:6),
+#'                         rules = validate::validator(a > 0, b > 0)),
+#'                time = Sys.time())
+#'                }
+#' 
 #' @export
 certificate_df <- function(x, time = Sys.time()){
     formatted_time <- format(as.POSIXlt(time, origin = "1970-01-01", tz = "GMT"), "%Y-%m-%d %H:%M:%S")
@@ -22,11 +29,12 @@ certificate_df <- function(x, time = Sys.time()){
                                        Sys.info())))
 }
 
-#' Read rules from a file
+#' @title Read rules from a file
 #'
+#' @description
 #' This function reads rules from a file or a data frame.
 #' The file can be in csv or xlsx format.
-#' The data should have the column names "name", "description", "severity", "rule".
+#' The data should have the column names "name", "description", "dataset", "valid example", "severity", "rule".
 #' The function also checks that the rules do not contain sensitive words and that
 #' all the rules fields are character type.
 #'
@@ -79,14 +87,14 @@ read_rules <- function(file_rules){
     return(rules)
 }
 
-#' Read and format data from csv or xlsx files
+#' @title Read and format data from csv or xlsx files
 #'
 #' @param files_data List of files to be read
 #' @param data_names Optional vector of names for the data frames
 #' @importFrom readxl excel_sheets
 #' @examples
-#' ## You can add examples of function usage here.
-#'
+#' read_data(files_data = valid_example, data_names = c("methodology", "particles", "samples"))
+#' 
 #' @return A list of data frames
 #' @export
 read_data <- function(files_data, data_names = NULL){
@@ -136,9 +144,9 @@ read_data <- function(files_data, data_names = NULL){
     data_formatted
 }
 
-#' Name datasets
+#' @title Name datasets
 #'
-#' This function extracts the names of the datasets provided in the input files.
+#' @description This function extracts the names of the datasets provided in the input files.
 #' If specific data names are provided, they are used, otherwise the function tries
 #' to extract the names from the files themselves.
 #'
@@ -168,9 +176,9 @@ name_data <- function(files_data, data_names = NULL){
 }
 
 
-#' Reformats the rules
+#' @title Reformat the rules
 #'
-#' This function is responsible for handling the rule reformating, dataset handling
+#' @description This function is responsible for handling the rule reformating, dataset handling
 #' and foreign key checks.
 #'
 #' @param rules A data.frame containing rules to be reformatted.
@@ -243,7 +251,7 @@ reformat_rules <- function(rules, data_formatted, zip_data = NULL){
 }
 
 
-#' Validate_data: Validate data based on specified rules.
+#' @title Validate data based on specified rules
 #'
 #' @param files_data A list of file paths for the datasets to be validated.
 #' @param data_names (Optional) A character vector of names for the datasets. If not provided, names will be extracted from the file paths.
@@ -394,17 +402,17 @@ validate_data <- function(files_data, data_names = NULL, file_rules = NULL, zip_
          issues = any_issues)
 }
 
-#' Remote Share Function
+#' @title Share your validated data
 #'
-#' This function uploads validated data to specified remote repositories,
-#' such as CKAN, Amazon S3, and/or MongoDB
+#' @description This function uploads validated data to specified remote repositories,
+#' such as CKAN, Amazon S3, and/or MongoDB.
 #'
 #' @param validation A list containing validation information.
 #' @param data_formatted A list containing formatted data.
 #' @param files A vector of file paths to upload.
 #' @param verified The secret key provided by the portal maintainer.
 #' @param valid_rules A list of valid rules for the dataset.
-#' @param valid_key A list of valid keys.
+#' @param valid_key_share A valid key to share data.
 #' @param ckan_url The URL of the CKAN instance.
 #' @param ckan_key The API key for the CKAN instance.
 #' @param ckan_package The CKAN package to which the data will be uploaded.
@@ -428,13 +436,32 @@ validate_data <- function(files_data, data_names = NULL, file_rules = NULL, zip_
 #' @importFrom utils write.csv read.csv zip
 #' @import mongolite
 #' @import jsonlite
-#'
 #' @examples
-#' #Need to add.
-#'
+#' \dontrun{
+#' shared_data <- remote_share(validation = result_valid,
+#'                             data_formatted = result_valid$data_formatted,
+#'                             files = test_file,
+#'                             verified = "your_verified_key",
+#'                             valid_key_share = "your_valid_key_share",
+#'                             valid_rules = digest::digest(test_rules),
+#'                             ckan_url = "https://example.com",
+#'                             ckan_key = "your_ckan_key",
+#'                             ckan_package = "your_ckan_package",
+#'                             url_to_send = "https://your-url-to-send.com",
+#'                             rules = test_rules,
+#'                             results = valid_example$results,
+#'                             s3_key_id = "your_s3_key_id",
+#'                             s3_secret_key = "your_s3_secret_key",
+#'                             s3_region = "your_s3_region",
+#'                             s3_bucket = "your_s3_bucket",
+#'                             mongo_key = "your_mongo_key",
+#'                             mongo_collection = "your_mongo_collection",
+#'                             old_cert = NULL
+#' )
+#' }
 #' @export
 
-remote_share <- function(validation, data_formatted, files, verified, valid_rules, valid_key, ckan_url, ckan_key, ckan_package, url_to_send, rules, results, s3_key_id, s3_secret_key, s3_region, s3_bucket, mongo_key, mongo_collection, old_cert = NULL){
+remote_share <- function(validation, data_formatted, files, verified, valid_rules, valid_key_share, ckan_url, ckan_key, ckan_package, url_to_send, rules, results, s3_key_id, s3_secret_key, s3_region, s3_bucket, mongo_key, mongo_collection, old_cert = NULL){
     
     use_ckan <- isTruthy(ckan_url) & isTruthy(ckan_key) & isTruthy(ckan_package)
     use_s3 <- isTruthy(s3_bucket)
@@ -452,7 +479,7 @@ remote_share <- function(validation, data_formatted, files, verified, valid_rule
         stop("If you are using a key to upload data to a remote repo then there must be a valid pair with the rules you are using in our internal database.")
     }
     
-    if(!any(verified %in% valid_key)){
+    if(!any(verified %in% valid_key_share)){
         stop("You must have a valid key provided by the portal maintainer to use this feature.")
     }
     
@@ -528,9 +555,9 @@ remote_share <- function(validation, data_formatted, files, verified, valid_rule
                 submission_time = submission_time))
 }
 
-#' Download Structured Data from Remote Sources
+#' @title Download structured data from remote sources
 #'
-#' This function downloads data from remote sources like CKAN, AWS S3.
+#' @description This function downloads data from remote sources like CKAN, AWS S3, and MongoDB.
 #' It retrieves the data based on the hashed_data identifier and assumes the data is stored using the same naming conventions provided in the `remote_share` function.
 #'
 #' @param hashed_data A character string representing the hashed identifier of the data to be downloaded.
@@ -541,6 +568,8 @@ remote_share <- function(validation, data_formatted, files, verified, valid_rule
 #' @param s3_secret_key A character string representing the AWS S3 secret access key.
 #' @param s3_region A character string representing the AWS S3 region.
 #' @param s3_bucket A character string representing the AWS S3 bucket name.
+#' @param mongo_key A character string representing the mongo key.
+#' @param mongo_collection A character string representing the mongo collection.
 #'
 #' @importFrom shiny isTruthy
 #' @importFrom dplyr mutate_if
@@ -622,9 +651,9 @@ remote_download <- function(hashed_data = NULL, ckan_url, ckan_key, ckan_package
     return(data_downloaded)
 }
 
-#' Download Raw Data from Remote Sources
+#' @title Download raw data from remote sources
 #'
-#' This function downloads data from remote sources like CKAN and AWS S3.
+#' @description This function downloads data from remote sources like CKAN and AWS S3.
 #' It retrieves the data based on the hashed_data identifier and assumes the data is stored using the same naming conventions provided in the `remote_share` function.
 #'
 #' @param hashed_data A character string representing the hashed identifier of the data to be downloaded.
@@ -692,9 +721,64 @@ remote_raw_download <- function(hashed_data = NULL, file_path = NULL, ckan_url =
     }
 }
 
-#' Check if an object is of class POSIXct
+#' @title Download all data alternative
+#' 
+#' @description This function allows users to download all data rather than one data set at a time.
+#' 
+#' @param file_path location and name of the zip file to create.
+#' @param s3_key_id A character string representing the AWS S3 access key ID.
+#' @param s3_secret_key A character string representing the AWS S3 secret access key.
+#' @param s3_region A character string representing the AWS S3 region.
+#' @param s3_bucket A character string representing the AWS S3 bucket name.
+#' @param callback Prints if the download was a success.
+#' 
+#' @importFrom shiny isTruthy
+#' @importFrom aws.s3 get_bucket get_object save_object
+#' @importFrom ckanr ckanr_setup package_show ckan_fetch
 #'
-#' This function checks if the given object is of class POSIXct.
+#' @return Any return objects from the downloads.
+#' 
+#' @examples
+#' \dontrun{
+#'     download_all_data <- download_all(file_path = "your/path/file.zip",
+#'                                       s3_key_id = "your_s3_key_id",
+#'                                       s3_secret_key = "your_s3_secret_key",
+#'                                       s3_region = "your_s3_region",
+#'                                       s3_bucket = "your_s3_bucket",
+#'                                       callback = NULL)
+#' }
+#' 
+#' @export
+download_all <- function(file_path = NULL, s3_key_id = NULL, s3_secret_key = NULL, s3_region = NULL, s3_bucket = NULL, callback = NULL) {
+    use_s3 <- shiny::isTruthy(s3_bucket)
+    
+    if (use_s3) {
+        Sys.setenv(
+            "AWS_ACCESS_KEY_ID" = s3_key_id,
+            "AWS_SECRET_ACCESS_KEY" = s3_secret_key,
+            "AWS_DEFAULT_REGION" = s3_region
+        )
+        # Retrieve a list of objects from S3 bucket
+        s3_objects <- get_bucket(bucket = s3_bucket)
+        for (object in s3_objects) {
+            success <- tryCatch({
+                aws.s3::save_object(object = object$Key, file = file.path(file_path, basename(object$Key)), bucket = s3_bucket)
+                TRUE  # Return TRUE if download is successful
+            }, error = function(e) {
+                FALSE  # Return FALSE if an error occurs during download
+            })
+        }
+        
+        # Call the callback function with the success status
+        if (!is.null(callback)) {
+            callback(success)
+        }
+    }
+}
+
+#' @title Check if an object is of class POSIXct
+#'
+#' @description This function checks if the given object is of class POSIXct.
 #' It returns TRUE if the object inherits the POSIXct class, otherwise FALSE.
 #'
 #' @param x An object to be tested for POSIXct class inheritance.
@@ -709,7 +793,7 @@ remote_raw_download <- function(hashed_data = NULL, file_path = NULL, ckan_url =
 #' @export
 is.POSIXct <- function(x) inherits(x, "POSIXct")
 
-#' rules_broken ----
+#' Check which rules were broken
 #'
 #' Filter the results of validation to show only broken rules, optionally including successful decisions.
 #'
@@ -739,9 +823,9 @@ rules_broken <- function(results, show_decision){
         select("description", "status", "name", "expression", everything())
 }
 
-#' rows_for_rules
+#' @title Check which rows in the data violated the rules
 #'
-#' Get the rows in the data that violate the specified rules.
+#' @description Get the rows in the data that violate the specified rules.
 #'
 #' @param data_formatted A formatted data frame.
 #' @param report A validation report generated by the 'validate' function.
@@ -798,9 +882,9 @@ rows_for_rules <- function(data_formatted,
 }
 
 #acknowledgement https://github.com/adamjdeacon/checkLuhn/blob/master/R/checkLuhn.R
-#' Check if a number passes the Luhn algorithm
+#' @title Check if a number passes the Luhn algorithm
 #'
-#' This function checks if a given number passes the Luhn algorithm. It is commonly used to validate credit card numbers.
+#' @description This function checks if a given number passes the Luhn algorithm. It is commonly used to validate credit card numbers.
 #' @param number A character string of the number to check against the Luhn algorithm.
 #' @return A logical value indicating whether the number passes the Luhn algorithm (TRUE) or not (FALSE).
 #' @examples
@@ -839,9 +923,10 @@ checkLuhn <- function(number) {
     ((sum(digits) %% 10) == 0)
 }
 
-#' Check if a file exists in a zip file
+#' @title Check if a file exists in a zip file
 #'
-#' This function checks if a file with a given name exists in a specified zip file.
+#' @description This function checks if a file with a given name exists in a specified zip file.
+#' 
 #' @param zip_path A character string representing the path of the zip file.
 #' @param file_name A character string representing the name of the file to check.
 #' @return A logical value indicating whether the file exists in the zip file (TRUE) or not (FALSE).
@@ -860,9 +945,10 @@ check_exists_in_zip <- function(zip_path, file_name) {
     return(file_exists)
 }
 
-#' Check and format image URLs
+#' @title Check and format image URLs
 #'
-#' This function checks if the input string contains an image URL (PNG or JPG) and formats it as an HTML img tag with a specified height.
+#' @description This function checks if the input string contains an image URL (PNG or JPG) and formats it as an HTML img tag with a specified height.
+#' 
 #' @param x A character string to check for image URLs.
 #' @return A character string with the HTML img tag if an image URL is found, otherwise the input string.
 #' @examples
@@ -876,9 +962,10 @@ check_images <- function(x){
            x)
 }
 
-#' Check and format non-image hyperlinks
+#' @title Check and format non-image hyperlinks
 #'
-#' This function checks if the input string contains a non-image hyperlink and formats it as an HTML anchor tag.
+#' @description This function checks if the input string contains a non-image hyperlink and formats it as an HTML anchor tag.
+#' 
 #' @param x A character string to check for non-image hyperlinks.
 #' @return A character string with the HTML anchor tag if a non-image hyperlink is found, otherwise the input string.
 #' @examples
@@ -892,9 +979,10 @@ check_other_hyperlinks <- function(x){
            x)
 }
 
-#' Test for profanity in a string
+#' @title Test for profanity in a string
 #'
-#' This function checks if the input string contains any profane words.
+#' @description This function checks if the input string contains any profane words.
+#' 
 #' @param x A character string to check for profanity.
 #' @return A logical value indicating whether the input string contains no profane words.
 #' @import lexicon
@@ -915,11 +1003,13 @@ test_profanity <- function(x){
         all()
 }
 
-#Rules to excel
-#' Create a formatted Excel file based on validation rules
+#' @title Create a formatted Excel file based on validation rules
 #'
-#' This function creates an Excel file with conditional formatting and data validation
+#' @description This function creates an Excel file with conditional formatting and data validation
 #' based on the given validation rules in a CSV or Excel file.
+#' This function is currently compatible with Windows and Linux operating systems. When using a macOS system,
+#' the excel file is able to download, but has some bugs with formatting the LOOKUP sheet.
+#' 
 #' @param file_rules A CSV or Excel file containing validation rules.
 #' @param negStyle Style to apply for negative conditions (default is red text on a pink background).
 #' @param posStyle Style to apply for positive conditions (default is green text on a light green background).
@@ -927,7 +1017,7 @@ test_profanity <- function(x){
 #' @return A workbook object containing the formatted Excel file.
 #' @importFrom readr read_csv
 #' @importFrom readxl read_excel
-#' @importFrom dplyr filter mutate bind_rows
+#' @importFrom dplyr filter mutate bind_rows %>%
 #' @importFrom data.table rbindlist
 #' @importFrom validate validator variables violating
 #' @importFrom openxlsx createWorkbook addWorksheet writeData freezePane dataValidation conditionalFormatting saveWorkbook createStyle protectWorksheet
@@ -935,9 +1025,10 @@ test_profanity <- function(x){
 #' @importFrom utils read.csv
 #' @importFrom rlang .data
 #' @examples
-#'
+#' \donttest{
 #' data("test_rules")
 #' create_valid_excel(file_rules = test_rules)
+#' }
 #' @export
 create_valid_excel <- function(file_rules,
                                negStyle  = createStyle(fontColour = "#9C0006", bgFill = "#FFC7CE"),
@@ -1084,9 +1175,9 @@ create_valid_excel <- function(file_rules,
     wb
 }
 
-#' Check for Malicious Files
+#' @title Check for malicious files
 #'
-#' This function checks for the presence of files with extensions known to be associated with malicious activities.
+#' @description This function checks for the presence of files with extensions known to be associated with malicious activities.
 #' The function can be used to screen zip files or individual files for these potentially dangerous file types.
 #'
 #' @param files A character vector of file paths. These can be paths to zip files or individual files.
@@ -1130,9 +1221,9 @@ check_for_malicious_files <- function(files) {
     return(FALSE)
 }
 
-#' Query MongoDB Document by ObjectID
+#' @title Query a MongoDB document by an ObjectID
 #'
-#' This function queries a mongodb database using its API to retrieve a document by its ObjectID. Use the MongoDB Atlas Data API to create an API key.
+#' @description This function queries a mongodb database using its API to retrieve a document by its ObjectID. Use the MongoDB Atlas Data API to create an API key.
 #' 
 #' @param collection The name of the collection in the MongoDB database.
 #' @param database The name of the MongoDB database.
@@ -1187,13 +1278,12 @@ query_document_by_object_id <- function(apiKey, collection, database, dataSource
     }
     }
 
-#' @title Run Validator app
+#' @title Run any of the apps
 #'
-#' @description
-#' This wrapper function starts the user interface of the validator app.
+#' @description This wrapper function starts the user interface of your app choice.
 #'
 #' @details
-#' After running this function the validator GUI should open in a separate
+#' After running this function the Validator, Microplastic Image Explorer, or Data Visualization GUI should open in a separate
 #' window or in your computer browser.
 #'
 #' @param path to store the downloaded app files; defaults to \code{"system"}
@@ -1202,6 +1292,7 @@ query_document_by_object_id <- function(apiKey, collection, database, dataSource
 #' @param ref git reference; could be a commit, tag, or branch name. Defaults to
 #' "main". Only change this in case of errors.
 #' @param test_mode logical; for internal testing only.
+#' @param app your app choice
 #' @param \dots arguments passed to \code{\link[shiny]{runApp}()}.
 #'
 #' @return
@@ -1210,7 +1301,7 @@ query_document_by_object_id <- function(apiKey, collection, database, dataSource
 #'
 #' @examples
 #' \dontrun{
-#' run_app()
+#' run_app(app = "validator")
 #' }
 #'
 #' @author
@@ -1222,17 +1313,25 @@ query_document_by_object_id <- function(apiKey, collection, database, dataSource
 #' @importFrom shiny runGitHub shinyOptions
 #' @importFrom utils installed.packages
 #' @export
-run_app <- function(path = "system", log = TRUE, ref = "main",
-                    test_mode = FALSE, ...) {
+run_app <- function(path = "system", log = TRUE, ref = "main", test_mode = FALSE, app = "validator", ...) {
     pkg <- c("shiny", "dplyr", "DT", "shinythemes", "shinyWidgets", "validate", "digest", "data.table",
              "bs4Dash", "ckanr", "purrr", "shinyjs", "sentimentr", "listviewer", "RCurl", "readxl", "stringr",
-             "openxlsx", "config", "aws.s3", "One4All", "mongolite")
+             "openxlsx", "config", "aws.s3", "One4All", "mongolite", "leaflet", "plotly", "readr", "tidyverse", "tidygeocoder", "sf",
+             "mapview", "mapdata", "data.table", "ggdist", "ggthemes", "ggplot2", "rlang", "PupillometryR", "gridExtra", "networkD3", "tidyr",
+             "janitor", "jsonlite", "httr", "googlesheets4", "curl")
     
     miss <- pkg[!(pkg %in% installed.packages()[ , "Package"])]
     
     if(length(miss)) stop("run_app() requires the following packages: ",
                           paste(paste0("'", miss, "'"), collapse = ", "),
-                          call. = F)
+                          call. = FALSE)
+    
+    app_dirs <- c("validator" = "inst/apps/validator",
+                  "data_visualization" = "inst/apps/data_visualization",
+                  "microplastic_image_explorer" = "inst/apps/microplastic_image_explorer")
+    
+    app_dir <- app_dirs[[app]]
+    if(is.null(app_dir)) stop("Invalid app specified. Available apps: validator, data_visualization, microplastic_image_explorer")
     
     dd <- ifelse(path == "system",
                  system.file(package = "One4All"),
@@ -1242,5 +1341,5 @@ run_app <- function(path = "system", log = TRUE, ref = "main",
     
     options(shiny.logfile = log)
     if(!test_mode)
-        runGitHub("Microplastic_Data_Portal", "Moore-Institute-4-Plastic-Pollution-Res", subdir = "code/validator")
-}
\ No newline at end of file
+        runGitHub("One4All", "Moore-Institute-4-Plastic-Pollution-Res", ref = ref, subdir = app_dir)
+}
